/*
 * Copyright 2012, 2013 Sebastian Neuser
 *
 * This file is part of SoundOrganizer.
 *
 * SoundOrganizer is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SoundOrganizer is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SoundOrganizer.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.haggl.soundorganizer;

import org.haggl.soundorganizer.data.Song;
import org.haggl.soundorganizer.database.DatabaseAssistant;
import org.haggl.soundorganizer.R;

import android.app.ExpandableListActivity;
import android.content.Intent;
import android.gesture.Gesture;
import android.gesture.GestureLibraries;
import android.gesture.GestureLibrary;
import android.gesture.GestureOverlayView;
import android.gesture.GestureOverlayView.OnGesturePerformedListener;
import android.gesture.Prediction;
import android.os.Bundle;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ExpandableListView;
import android.widget.TextView;


/**
 * Displays a list of all songs.
 * @author haggl
 */
public class SongActivity extends ExpandableListActivity implements OnGesturePerformedListener
{
	// DEBUG variables
	protected static final String TAG = SongActivity.class.getSimpleName();
	
	// state variables
	private DatabaseAssistant assistant;
	private Song song;
	private GestureLibrary gestures;
	
	@Override
	public void onCreate( Bundle savedInstanceState )
	{
		super.onCreate( savedInstanceState );
		requestWindowFeature( Window.FEATURE_NO_TITLE );
		setContentView( R.layout.song_layout );
		
		// fetch song and direction
		assistant = DatabaseAssistant.getInstance();
		assistant.open();
		song = assistant.getSong( getIntent().getExtras().getLong( "songID" ) );
		
		// load gestures and initialize gesture listener
		gestures = GestureLibraries.fromRawResource( this, R.raw.gestures );
		if (!gestures.load()) finish();
		
		GestureOverlayView gestures = (GestureOverlayView) findViewById( R.id.gestureOverlay );
		gestures.addOnGesturePerformedListener(this);
		
		// fill the ListView with data
		((TextView) findViewById( R.id.song_title )).setText( song.getTitle() );
		setListAdapter( new DeviceListAdapter( (ExpandableListView) findViewById( android.R.id.list ), song.getID() ) );
		
		// ignore screen lock and request fullscreen
		getWindow().addFlags( WindowManager.LayoutParams.FLAG_SHOW_WHEN_LOCKED );
		getWindow().addFlags( WindowManager.LayoutParams.FLAG_FULLSCREEN );
	}
	
	@Override
	public void onGesturePerformed( GestureOverlayView overlay, Gesture gesture )
	{
	    for (Prediction currentPrediction : gestures.recognize( gesture ))
	        if (currentPrediction.score > 1.0)
	        {
	        	if (song.getNumber() == null) return; // ignore gestures on unlisted songs
	        	
	        	// start a new activity and provide it with the next/previous song
				Intent nextIntent = new Intent( getApplicationContext(), SongActivity.class );
	        	if (currentPrediction.name.equals( "left" ) && song.getNumber() > 1)
					nextIntent.putExtra( "songID", assistant.findSongID( (short) (song.getNumber()-1) ) );
	        	else if (song.getNumber() < assistant.countSongsWithNumbers())
					nextIntent.putExtra( "songID", assistant.findSongID( (short) (song.getNumber()+1) ) );
				startActivity( nextIntent );
        		overridePendingTransition( 0, 0 );
				finish();
		    }
	}
}